@@ -44,8 +44,9 @@ case "$WMCLASS" in
 		CHOICES="
 			$icon_plk Modem PIN                ^ 0 ^ sxmo_unlocksim.sh
 			$icon_phn Modem Monitor $(
-				sxmo_daemons.sh running modem_monitor -q &&
-				printf %b "$icon_ton ^ 1 ^ sxmo_daemons.sh stop modem_monitor" || printf %b "$icon_tof ^ 1 ^ sxmo_daemons.sh start modem_monitor sxmo_modemmonitor.sh"
+				superd_service_isrunning sxmo_modemmonitor &&
+				printf %b "$icon_ton ^ 1 ^ superctl stop sxmo_modemmonitor" ||
+				printf %b "$icon_tof ^ 1 ^ superctl start sxmo_modemmonitor"
 			) && sxmo_hook_statusbar.sh modem_monitor
 			$icon_wrh Restart System Daemons     ^ 1 ^ sxmo_hook_restart_modem_daemons.sh && sxmo_hook_statusbar.sh modem
 			$icon_inf Modem Info                 ^ 0 ^ sxmo_modeminfo.sh
@@ -83,25 +84,22 @@ case "$WMCLASS" in
 			$(test "$SXMO_WM" = dwm && printf %b "$icon_cfg Invert Colors ^ 1 ^ xcalib -a -invert")
 			$icon_clk Change Timezone            ^ 1 ^ sxmo_timezonechange.sh
 			$icon_zzz Auto-suspend $(
-				[ -e "$XDG_CACHE_HOME/sxmo/sxmo.nosuspend" ] && printf "%s" "$icon_tof" || printf "%s" "$icon_ton"
-			) ^ 1 ^ rm "$XDG_CACHE_HOME/sxmo/sxmo.nosuspend" || touch "$XDG_CACHE_HOME/sxmo/sxmo.nosuspend"
+				[ -e "$XDG_CACHE_HOME"/sxmo/sxmo.nosuspend ] && printf "%s" "$icon_tof" || printf "%s" "$icon_ton"
+			) ^ 1 ^ (rm $XDG_CACHE_HOME/sxmo/sxmo.nosuspend || touch $XDG_CACHE_HOME/sxmo/sxmo.nosuspend)
 			$icon_zzz Auto-screen-off $(
 				[ -e "$XDG_CACHE_HOME/sxmo/sxmo.noidle" ] && printf "%s" "$icon_tof" || printf "%s" "$icon_ton"
-			) ^ 1 ^ (rm "$XDG_CACHE_HOME/sxmo/sxmo.noidle" || touch "$XDG_CACHE_HOME/sxmo/sxmo.noidle") && sxmo_hook_unlock.sh
+			) ^ 1 ^ (rm $XDG_CACHE_HOME/sxmo/sxmo.noidle || touch $XDG_CACHE_HOME/sxmo/sxmo.noidle) && sxmo_hook_unlock.sh
 			$icon_ror Autorotate $(
 				sxmo_daemons.sh running autorotate -q &&
 				printf "%s" "$icon_ton" || printf "%s" "$icon_tof"
 			) ^ 1 ^ toggle_daemon 'Autorotate' autorotate sxmo_autorotate.sh
-			$icon_lck Proximity Lock $(
-				sxmo_daemons.sh running proximity_lock -q &&
-				printf "%s" "$icon_ton" || printf "%s" "$icon_tof"
-			) ^ 1 ^ toggle_daemon 'Proximity Lock' proximity_lock sxmo_hook_proximitylock.sh
 			$icon_ror Rotate                     ^ 1 ^ sxmo_rotate.sh rotate
 			$icon_trm Hooks                      ^ 0 ^ sxmo_hookmenu.sh
 			$icon_upc Upgrade Pkgs               ^ 0 ^ sxmo_terminal.sh sxmo_upgrade.sh
 			$icon_sfl Migrate configuration      ^ 0 ^ sxmo_terminal.sh sxmo_migrate.sh
 			$icon_cfg Edit configuration         ^ 0 ^ sxmo_terminal.sh $EDITOR $XDG_CONFIG_HOME/sxmo/$(test "$SXMO_WM" = sway && printf sway || printf xinit)
 			$(command -v pmos-tweaks >/dev/null && echo "$icon_cfg PostmarketOS Tweaks	     ^ 0 ^ GDK_SCALE=1 pmos-tweaks")
+			$icon_cfg Suspend Blockers           ^ 0 ^ sxmo_terminal.sh sxmo_wakelock.sh debug watch
 			$icon_inf Version                    ^ 0 ^ sxmo_terminal.sh sxmo_version.sh --block
 		"
 		WINNAME=Config
@@ -111,7 +109,6 @@ case "$WMCLASS" in
 		CHOICES="
 			$icon_lck Lock               ^ 0 ^ sxmo_hook_lock.sh
 			$icon_lck Lock (Screen off)  ^ 0 ^ sxmo_hook_screenoff.sh
-			$icon_zzz Suspend            ^ 0 ^ sxmo_hook_screenoff.sh && sxmo_suspend.sh
 			$icon_out Logout             ^ 0 ^ confirm Logout && sxmo_power.sh logout
 			$([ -f "$(xdg_data_path xsessions/sxmo.desktop)" ] &&
 				[ -f "$(xdg_data_path wayland-sessions/swmo.desktop)" ] &&
@@ -128,8 +125,8 @@ case "$WMCLASS" in
 			$icon_pau Pause        ^ 0 ^ sxmo_type -k Space
 			$icon_fbw Seek       ^ 1 ^ sxmo_type -k Left
 			$icon_ffw Seek       ^ 1 ^ sxmo_type -k Right
-			$icon_aru App Volume ↑ ^ 1 ^ sxmo_type 0
-			$icon_ard App Volume ↓ ^ 1 ^ sxmo_type 9
+			$icon_aru App Volume Up ^ 1 ^ sxmo_type 0
+			$icon_ard App Volume Down ^ 1 ^ sxmo_type 9
 			$icon_aru Speed up      ^ 1 ^ sxmo_type -k bracketRight
 			$icon_ard Speed down    ^ 1 ^ sxmo_type -k bracketLeft
 			$icon_cam Screenshot   ^ 1 ^ sxmo_type s
@@ -171,6 +168,19 @@ case "$WMCLASS" in
 		"
 		WINNAME=Sxiv
 		;;
+	*imv*)
+		# imv
+		CHOICES="
+			$icon_arr Next          ^ 1 ^ sxmo_type -k Right
+			$icon_arl Previous      ^ 1 ^ sxmo_type -k Left
+			$icon_zmi Zoom in       ^ 1 ^ sxmo_type -k i
+			$icon_zmo Zoom out      ^ 1 ^ sxmo_type -k minus
+			$icon_exp Zoom to fit   ^ 1 ^ sxmo_type -k r
+			$icon_ror Rotate        ^ 1 ^ sxmo_type -M ctrl r
+			$icon_inf Toggle filename ^ 1 ^ sxmo_type -k d
+		"
+		WINNAME=Imv
+		;;
 	*kasts*)
 		CHOICES="
 			$icon_mus Audio ^ 0 ^ sxmo_audio.sh
@@ -193,7 +203,7 @@ case "$WMCLASS" in
 		"
 		WINNAME=St
 		;;
-	*foot*|*st*|*terminal*)
+	*foot*|*st*|*terminal*|org.gnome.vte.application|*alacritty*)
 		# First we try to handle the app running inside the terminal:
 		WMNAME="${1:-$(printf %s "$XPROPOUT" | grep title: | cut -d" " -f2- | tr '[:upper:]' '[:lower:]')}"
 		if printf %s "$WMNAME" | grep -qi -E -w "(vi|vim|vis|nvim|neovim|kakoune)"; then
@@ -358,9 +368,8 @@ case "$WMCLASS" in
 				$icon_mnu Terminal menu ^ 0 ^ sxmo_appmenu.sh $WMCLASS
 			"
 			WINNAME=weechat
-		elif printf %s "$WMNAME" | grep -qi -w "sms"; then
-			# TODO: Ensure $number is valid.
-			number="$(printf %s "$WMNAME" | sed -e 's|^\"||' -e 's|\"$||' | cut -f1 -d' ')"
+		elif printf %s "$WMNAME" | grep -qi -w "sms\|missed call"; then
+			number="$(printf "%s\n" "$WMNAME" | xargs -0 pnc find | tr -d '\n')"
 			#sms
 			CHOICES="
 				$icon_msg Conversation   ^ 0 ^ sxmo_terminal.sh sxmo_modemtext.sh conversationloop $number
@@ -369,7 +378,7 @@ case "$WMCLASS" in
 				$([ -d "$SXMO_LOGDIR/$number/attachments" ] && echo "$icon_att View Attachments ^ 1 ^ sxmo_files.sh $SXMO_LOGDIR/$number/attachments --date-sort")
 				$(
 
-				found_numbers="$(printf %s "$number" | xargs -I{} pn find "{}")"
+				found_numbers="$(printf %s "$number" | xargs -I{} pnc find "{}")"
 				printf "%s\n" "$found_numbers" | while read -r line; do
 					sxmo_contacts.sh --name "$line" | grep -q '???' && echo "$icon_usr Add $line ^ 1 ^ sxmo_contactmenu.sh newcontact $line"
 				done
@@ -383,7 +392,7 @@ case "$WMCLASS" in
 				$icon_ard Scroll down     ^ 1 ^ sxmo_type -M Shift -M Ctrl f
 				$icon_mnu Terminal menu ^ 0 ^ sxmo_appmenu.sh $WMCLASS
 			"
-			WINNAME=sms
+			WINNAME=phone
 		elif printf %s "$WMNAME" | grep -qi -w "cmus"; then
 			# cmus
 			# requires `:set set_term_title=false` in cmus to match the application
@@ -409,10 +418,10 @@ case "$WMCLASS" in
 						$icon_itm Type complete   ^ 0 ^ sxmo_type -M Ctrl -M Shift -k u
 						$icon_cpy Copy complete   ^ 0 ^ sxmo_type -M Ctrl -M Shift -k i
 						$icon_itm Selmode $(
-						  [ "$STSELMODEON" = 1 ] &&
-						  printf %b "$icon_ton" ||
-						  printf %b "$icon_tof"
-						  printf %b '^ 0 ^ sxmo_type -M Ctrl -M Shift -k s'
+							[ "$STSELMODEON" = 1 ] &&
+							printf %b "$icon_ton" ||
+							printf %b "$icon_tof"
+							printf %b '^ 0 ^ sxmo_type -M Ctrl -M Shift -k s'
 						)
 						$([ "$STSELMODEON" = 1 ] && echo 'Copy selection ^ 0 ^ sxmo_type -M Ctrl -M Shift -k c')
 						$icon_pst Paste           ^ 0 ^ sxmo_type -M Ctrl -M Shift -k v
@@ -435,13 +444,30 @@ case "$WMCLASS" in
 						$icon_ard Scroll down     ^ 1 ^ sxmo_type -M Shift -k Next
 						$icon_lnk URL Mode        ^ 0 ^ sxmo_type -M Shift -M Ctrl -k u
 						$icon_kbd Hotkeys         ^ 0 ^ sxmo_appmenu.sh sthotkeys
+						$icon_fnd Search Field	  ^ 0 ^ sxmo_type -M Ctrl -M Shift -k r
+						$icon_aru Search Back	  ^ 0 ^ sxmo_type -M Ctrl -k r
+						$icon_ard Search Forward  ^ 0 ^ sxmo_type -M Ctrl -k s
+						$icon_itm Search Extend	  ^ 0 ^ sxmo_type -M Ctrl -k w
 					"
 					WINNAME=Foot
 					;;
-				*terminal*)
+				*terminal*|org.gnome.vte.application)
 					CHOICES="$icon_kbd Hotkeys ^ 0 ^ sxmo_appmenu.sh sthotkeys"
 					WINNAME=Terminal
 					;;
+				*alacritty*)
+					CHOICES="
+						$icon_cpy Copy				^ 0 ^ sxmo_type -M Shift -M Ctrl c
+						$icon_pst Paste				^ 0 ^ sxmo_type -M Shift -M Ctrl v
+						$icon_vim VI Mode			^ 0 ^ sxmo_type -M Ctrl -M Shift -k Space
+						$icon_fnd Search Forward	^ 0 ^ sxmo_type -M Ctrl -M Shift -k f
+						$icon_fnd Search Backward	^ 0 ^ sxmo_type -M Ctrl -M Shift -k b
+						$icon_aru Search Previous   ^ 0 ^ sxmo_type -k Enter
+						$icon_ard Search Next		^ 0 ^ sxmo_type -M Shift -k Enter
+						$icon_kbd Hotkeys 			^ 0 ^ sxmo_appmenu.sh sthotkeys
+					"
+					WINNAME=Alacritty
+					;;
 			esac
 		fi
 	;;
@@ -524,7 +550,24 @@ case "$WMCLASS" in
 		"
 		WINNAME=Surf
 		;;
-	*firefox*)
+	*falkon*)
+		# Falkon
+		CHOICES="
+			$icon_flt Pipe URL          ^ 0 ^ sxmo_urlhandler.sh
+			$icon_tab New Tab           ^ 0 ^ sxmo_type -M Ctrl t
+			$icon_win New Window        ^ 0 ^ sxmo_type -M Ctrl n
+			$icon_cls Close Tab         ^ 0 ^ sxmo_type -M Ctrl w
+			$icon_zmi Zoom            ^ 1 ^ sxmo_type -M Ctrl -k plus
+			$icon_zmo Zoom            ^ 1 ^ sxmo_type -M Ctrl -k minus
+			$icon_arl History        ^ 1 ^ sxmo_type -M Alt -k Left
+			$icon_arr History        ^ 1 ^ sxmo_type -M Alt -k Right
+			$icon_win Home           ^ 0 ^ sxmo_type -M Alt -k Home
+			$icon_zmo Full Screen    ^ 0 ^ sxmo_type -k F11
+			$icon_rld Refresh     ^ 0 ^ sxmo_type -M Shift -M Ctrl r
+		"
+		WINNAME=Falkon
+		;;
+	*firefox*|*navigator*)
 		# Firefox
 		CHOICES="
 			$icon_flt Pipe URL          ^ 0 ^ sxmo_urlhandler.sh
@@ -607,6 +650,7 @@ case "$WMCLASS" in
 		CHOICES="
 			$icon_grd Scripts                                            ^ 0 ^ sxmo_appmenu.sh scripts
 			$icon_grd Apps                                               ^ 0 ^ sxmo_appmenu.sh applications
+			$icon_grd Binaries                                           ^ 0 ^ sxmo_brun.sh
 			$icon_dir Files                                              ^ 0 ^ sxmo_files.sh
 			$icon_phn Dialer                                             ^ 0 ^ sxmo_modemdial.sh
 			$icon_msg Texts                                              ^ 0 ^ sxmo_modemtext.sh
@@ -619,7 +663,7 @@ case "$WMCLASS" in
 			$(
 				if [ -z "$SXMO_DISABLE_LEDS" ]; then
 					printf "%s Flashlight " "$icon_fll"
-					sxmo_uniq_exec.sh sxmo_led.sh get white | grep -vq ^100$ &&
+					sxmo_led.sh get white | grep -vq ^100$ &&
 						printf %b "$icon_tof" ||  printf %b "$icon_ton";
 					printf %b "^ 1 ^ sxmo_flashtoggle.sh"
 				fi
