@@ -12,6 +12,8 @@
 newstate="$2"
 # reason="$3" # 0 or 1
 
+sxmo_debug "$2 (old: $1 [reason: $3])"
+
 case "$newstate" in
 	"locked")
 		sxmo_log "State is locked.  Attempting to unlock."
@@ -19,6 +21,12 @@ case "$newstate" in
 			sxmo_unlocksim.sh
 		fi
 		;;
+	"enabling")
+		sxmo_log "State is enabling. Clearing stale call files."
+		rm "$XDG_RUNTIME_DIR"/sxmo_calls/* 2>/dev/null
+		rm -f "$XDG_RUNTIME_DIR"/sxmo.ring.pid 2>/dev/null
+		rm -f "$SXMO_NOTIFDIR"/incomingcall* 2>/dev/null
+		;;
 	"registered")
 		sxmo_log "State is registered.  Checking for calls and messages."
 
@@ -28,6 +36,7 @@ case "$newstate" in
 		sxmo_modem.sh checkforfinishedcalls
 		sxmo_modem.sh checkforincomingcalls
 		sxmo_modem.sh checkfornewtexts
+		sxmo_modem.sh checkforstucksms
 		if [ -f "${SXMO_MMS_BASE_DIR:-"$HOME"/.mms/modemmanager}/mms" ]; then
 			sxmo_mms.sh checkforlostmms
 		fi
