@@ -6,8 +6,9 @@
 
 # kill existing ring playback
 if [ -e "$XDG_RUNTIME_DIR/sxmo.ring.pid" ]; then
-	MPVID="$(cat "$XDG_RUNTIME_DIR/sxmo.ring.pid")"
-	kill "$MPVID"
+	xargs -r kill < "$XDG_RUNTIME_DIR/sxmo.ring.pid"
 	rm "$XDG_RUNTIME_DIR/sxmo.ring.pid"
 fi
 
+sxmo_playerctl.sh pause_all
+
