@@ -18,7 +18,7 @@ daemon_start() {
 		sxmo_notify_user.sh "$1 is already running"
 		return 0
 	fi
-	case "$OS" in
+	case "$SXMO_OS" in
 		alpine|postmarketos)
 			doas rc-service "$1" start
 			;;
@@ -38,7 +38,7 @@ daemon_stop() {
 		sxmo_notify_user.sh "$1 is already stopped"
 		return 0
 	fi
-	case "$OS" in
+	case "$SXMO_OS" in
 		alpine|postmarketos)
 			doas rc-service "$1" stop
 			;;
@@ -54,7 +54,7 @@ daemon_isrunning() {
 		sxmo_log "$1 does not exist on the system"
 		return 1
 	fi
-	case "$OS" in
+	case "$SXMO_OS" in
 		alpine|postmarketos)
 			rc-service "$1" status | grep -q started
 			;;
@@ -66,7 +66,7 @@ daemon_isrunning() {
 }
 
 daemon_exists() {
-	case "$OS" in
+	case "$SXMO_OS" in
 		alpine|postmarketos)
 			[ -f /etc/init.d/"$1" ]
 			;;
@@ -79,27 +79,25 @@ daemon_exists() {
 }
 
 if command -v eg25-manager > /dev/null; then
-	if daemon_isrunning eg25-manager; then
-		sxmo_notify_user.sh "Already running eg25-manager..."
-	else
-		sxmo_notify_user.sh "Starting eg25-manager..."
-		daemon_start eg25-manager
-		sleep 30
-	fi
+	sxmo_notify_user.sh "Stopping eg25-manager..."
+	daemon_stop eg25-manager
+	sleep 2
+	sxmo_notify_user.sh "Starting eg25-manager..."
+	daemon_start eg25-manager
 	if ! daemon_isrunning eg25-manager; then
 		sxmo_notify_user.sh --urgency=critical "The eg25-manager failed to start!"
 		exit 1
 	fi
 fi
 
-if daemon_isrunning modemmanager; then
-	sxmo_notify_user.sh "Already running modemmanager..."
-else
-	sxmo_notify_user.sh "Starting modemmanager..."
-	daemon_start modemmanager
-	sleep 5
-fi
+sxmo_notify_user.sh "Stopping modemmanager..."
+daemon_stop modemmanager
+sleep 2
+sxmo_notify_user.sh "Starting modemmanager..."
+daemon_start modemmanager
 if ! daemon_isrunning modemmanager; then
 	sxmo_notify_user.sh --urgency=critical "The modemmanager failed to start!"
 	exit 1
 fi
+# we want 120s before sleeping again
+sxmo_wakelock.sh lock modem_manually_reset 120s
