@@ -23,7 +23,7 @@ menu() {
 			sed 's/===/\n/g' |
 			sed 's/^\t//g' |
 			sort -t"$(printf '%b' '\t')" -rnk4 |
-			awk -F'\t' '{ printf "↑%4s", $3; print " " $4 " " $1 " " $2 }'
+			awk -F'\t' '{ printf "%4s", $3; print " " $4 " " $1 " " $2 }'
 	)"
 
 	while true; do
