@@ -5,7 +5,8 @@
 udev_tmp="$(mktemp)"
 udevadm monitor -u -s power_supply >> "$udev_tmp" &
 UDEVPID=$!
-tail -f "$udev_tmp" | while read -r; do
+# shellcheck disable=SC2034
+tail -f "$udev_tmp" | while read -r _; do
 	sxmo_hook_statusbar.sh battery
 done &
 STATUSBATTERYPID=$!
