@@ -7,19 +7,9 @@
 # shellcheck source=scripts/core/sxmo_common.sh
 . sxmo_common.sh
 
-# see sxmo_common.sh
-if [ -e /etc/os-release ]; then
-	# shellcheck source=/dev/null
-	. /etc/os-release
-elif [ -e /usr/lib/os-release ]; then
-	# shellcheck source=/dev/null
-	. /usr/lib/os-release
-fi
-export OS="${ID:-unknown}"
-
 on() {
 	rfkill unblock bluetooth
-	case "$OS" in
+	case "$SXMO_OS" in
 		alpine|postmarketos)
 			rc-service bluetooth start
 			rc-update add bluetooth
@@ -32,7 +22,7 @@ on() {
 }
 
 off() {
-	case "$OS" in
+	case "$SXMO_OS" in
 		alpine|postmarketos)
 			rc-service bluetooth stop
 			rc-update del bluetooth
