@@ -5,16 +5,6 @@
 # shellcheck source=scripts/core/sxmo_common.sh
 . sxmo_common.sh
 
-free_mutex() {
-	sxmo_mutex.sh can_suspend free "Playing with leds"
-	exit
-}
-
-ensure_mutex() {
-	sxmo_mutex.sh can_suspend lock "Playing with leds"
-	trap 'free_mutex' TERM INT
-}
-
 get_type() {
 	# Get type from variable name created dynamically from the color,
 	# e.g. $SXMO_LED_RED_TYPE
@@ -78,12 +68,21 @@ set_leds() {
 	wait
 }
 
+finish_blinking() {
+	sxmo_wakelock.sh unlock playing_with_leds
+	eval set_leds green '$'old_green blue '$'old_blue red '$'old_red ${white:+white '$'old_white}
+	exit
+}
+
 blink_leds() {
 	for color in green blue red white; do
 		percent="$(get_led "$color")"
 		eval "old_$color=$percent" # store old value
 	done
 
+	sxmo_wakelock.sh lock playing_with_leds 2s
+	trap 'finish_blinking' TERM INT EXIT
+
 	while [ -n "$1" ]; do
 		case "$1" in
 			green|blue|red|white)
@@ -105,21 +104,21 @@ blink_leds() {
 	set_leds green 0 blue 0 red 0 ${white:+white 0}
 
 	sleep 0.1 # Make blink noticable
-
-	eval set_leds green '$'old_green blue '$'old_blue red '$'old_red ${white:+white '$'old_white}
 }
 
 [ -z "$SXMO_DISABLE_LEDS" ] || exit 1
 
+exec 3<> "${XDG_RUNTIME_DIR:-$HOME}/sxmo.led.lock"
+
 cmd="$1"
 shift
 case "$cmd" in
 	"set"|blink)
-		ensure_mutex
+		flock -x 3
 		"$cmd"_leds "$@"
-		free_mutex
 		;;
 	get)
+		flock -s 3
 		get_led "$@"
 		;;
 esac
