@@ -130,28 +130,31 @@ addnetworkgsmmenu() {
 }
 
 addnetworkwpamenu() {
-	SSID="$(
-		nmcli d wifi list | tail -n +2 | grep -v '^\*' | awk -F'  ' '{ print $6 }' | grep -v '\-\-' |
-		xargs -0 printf "$icon_cls Close Menu\n%s" |
-		sxmo_dmenu_with_kb.sh -p "SSID"
+	SSID="$(cat <<EOF | sxmo_dmenu_with_kb.sh -p "SSID"
+$icon_cls Close Menu
+$(nmcli d wifi list | tail -n +2 | grep -v '^\*' | awk -F'  ' '{ print $6 }' | grep -v '\-\-')
+EOF
 	)"
 	[ -z "$SSID" ] && return
 	echo "$SSID" | grep -q "Close Menu" && return
 
-	PASSPHRASE="$(
-		echo "$icon_cls Close Menu" |
-			sxmo_dmenu_with_kb.sh -p "Passphrase"
+	PASSPHRASE="$(cat <<EOF | sxmo_dmenu_with_kb.sh -p "Passphrase"
+$icon_cls Close Menu
+None
+EOF
 	)"
-	[ -z "$PASSPHRASE" ] && return
+
+	if [ -z "$PASSPHRASE" ] || [ "None" = "$PASSPHRASE" ]; then
+		unset PASSPHRASE
+	fi
 	echo "$PASSPHRASE" | grep -q "Close Menu" && return
 
 	RES="$(nofail nmcli c add \
 		type wifi \
 		ifname wlan0 \
 		con-name "$SSID" \
-		802-11-wireless-security.key-mgmt wpa-psk \
 		ssid "$SSID" \
-		802-11-wireless-security.psk "$PASSPHRASE" 2>&1)"
+		${PASSPHRASE:+802-11-wireless-security.key-mgmt wpa-psk 802-11-wireless-security.psk "$PASSPHRASE"} 2>&1)"
 	stderr "$RES"
 	notify-send "$RES"
 }
@@ -236,6 +239,7 @@ networksmenu() {
 			rfkill list wifi | grep -q "yes" || WIFI_ENABLED=1
 
 			grep . << EOF | sxmo_dmenu.sh -p "Networks"
+$icon_cls Close Menu
 $(
 	if [ -z "$WIFI_ENABLED" ]; then
 		connections | grep -v "$icon_wif"
@@ -258,15 +262,10 @@ $(
 $icon_cfg Nmtui
 $icon_cfg Ifconfig
 $([ -z "$WIFI_ENABLED" ] || printf "%s Scan Wifi Networks\n" "$icon_wif")
-$icon_mnu System Menu
-$icon_cls Close Menu
 EOF
 		)" || exit
 
 		case "$CHOICE" in
-			*"System Menu" )
-				sxmo_appmenu.sh sys && exit
-				;;
 			*"Close Menu" )
 				exit
 				;;
@@ -294,11 +293,7 @@ EOF
 			*"Scan Wifi Networks" )
 				sxmo_terminal.sh watch -n 2 nmcli d wifi list || continue # Killeable
 				;;
-			*"Disable Wifi" )
-				doas sxmo_wifitoggle.sh
-				sxmo_hook_statusbar.sh network wifi wlan0
-				;;
-			*"Enable Wifi" )
+			*"Disable Wifi"|*"Enable Wifi" )
 				doas sxmo_wifitoggle.sh
 				;;
 			*)
