@@ -8,11 +8,11 @@
 . sxmo_common.sh
 
 # We can have multiple cronjobs at the same time
-sxmo_mutex.sh can_suspend lock "Executing cronjob"
-sxmo_mutex.sh can_suspend free "Waiting for cronjob"
+sxmo_wakelock.sh lock executing_cronjob_$$ infinite
+sxmo_wakelock.sh unlock waiting_cronjob
 
 finish() {
-	sxmo_mutex.sh can_suspend free "Executing cronjob"
+	sxmo_wakelock.sh unlock executing_cronjob_$$
 	exit 0
 }
 
