@@ -7,7 +7,7 @@
 # some device-specific permissions
 
 if [ -e /proc/device-tree/compatible ]; then
-    device="$(tr -c '\0[:alnum:].,-' '_' < /proc/device-tree/compatible |
+	device="$(tr -c '\0[:alnum:].,-' '_' < /proc/device-tree/compatible |
 			tr '\0' '\n' | head -n1)"
 	deviceprofile="$(command -v "sxmo_deviceprofile_$device.sh")"
 	# shellcheck disable=SC1090
@@ -18,8 +18,8 @@ fi
 # users can override this in sxmo_deviceprofile_mydevice.sh
 files="${SXMO_SYS_FILES:-"/sys/power/state /sys/power/mem_sleep /dev/rtc0"}"
 
-for file in $files; do
-    [ -e "$file" ] && chmod a+rw "$file"
+for file in $files /sys/power/wakeup_count; do
+	[ -e "$file" ] && chmod a+rw "$file"
 done
 
 chmod -R a+rw /sys/class/wakeup/*
