@@ -13,6 +13,11 @@ case "$SXMO_WM" in
 		/usr/bin/dwm -v
 		/usr/bin/dmenu -v
 		/usr/bin/st -v
+		if ! command -v bonsaictl > /dev/null; then
+			echo "no bonsai"
+		else
+			which bonsaictl
+		fi
 		;;
 	sway)
 		/usr/bin/sway -v
@@ -28,13 +33,15 @@ esac
 
 printf "superd "
 /usr/bin/superctl --version
+pactl info
 "$KEYBOARD" -v
 /usr/bin/mmcli --version | head -n 1
 uname -m
 . /etc/os-release
 printf "%s %s" "$NAME" "$VERSION"
 
+# shellcheck disable=SC2034
 if [ "$1" = "--block" ]; then
 	printf " (press return to exit)"
-	read -r
+	read -r _
 fi
