@@ -23,6 +23,8 @@ with_dbus() {
 }
 
 start() {
+	[ -f "$XDG_STATE_HOME"/sxmo.log ] && mv "$XDG_STATE_HOME"/sxmo.log "$XDG_STATE_HOME"/sxmo.log.old
+
 	if [ -z "$DBUS_SESSION_BUS_ADDRESS" ]; then
 		dbus-run-session -- "$0" "with_dbus"
 	else
@@ -36,6 +38,7 @@ cleanup() {
 	sxmo_daemons.sh stop all
 	pkill bemenu
 	pkill wvkbd
+	pkill superd
 }
 
 init() {
@@ -52,6 +55,7 @@ init() {
 	# shellcheck disable=SC1090,SC1091
 	. "$XDG_CONFIG_HOME/sxmo/profile"
 
+	cleanup
 	start
 	cleanup
 	sxmo_hook_stop.sh
