@@ -18,9 +18,6 @@ defaults() {
 	xmodmap "$(xdg_data_path sxmo/appcfg/xmodmap_caps_esc)"
 	xsetroot -mod 29 29 -fg '#0b3a4c' -bg '#082430'
 	xset s off -dpms
-	for xr in "$(xdg_data_path sxmo/appcfg)"/*.xr; do
-		xrdb -merge "$xr"
-	done
 	[ -e "$HOME"/.Xresources ] && xrdb -merge "$HOME"/.Xresources
 	SCREENWIDTH=$(xrandr | grep "Screen 0" | cut -d" " -f 8)
 	SCREENHEIGHT=$(xrandr | grep "Screen 0" | cut -d" " -f 10 | tr -d ",")
@@ -48,6 +45,8 @@ with_dbus() {
 }
 
 start() {
+	[ -f "$XDG_STATE_HOME"/sxmo.log ] && mv "$XDG_STATE_HOME"/sxmo.log "$XDG_STATE_HOME"/sxmo.log.old
+
 	if [ -z "$DBUS_SESSION_BUS_ADDRESS" ]; then
 		dbus-run-session -- "$0" "with_dbus"
 	else
@@ -61,6 +60,7 @@ cleanup() {
 	sxmo_daemons.sh stop all
 	pkill svkbd
 	pkill dmenu
+	pkill superd
 }
 
 init() {
@@ -77,6 +77,7 @@ init() {
 	# shellcheck disable=SC1090,SC1091
 	. "$XDG_CONFIG_HOME/sxmo/profile"
 
+	cleanup
 	start
 	cleanup
 	sxmo_hook_stop.sh
