@@ -11,10 +11,6 @@ export LIBGL_ALWAYS_SOFTWARE=true
 export SXMO_TOUCHSCREEN_ID="10"
 export SXMO_STYLUS_ID="12"
 export SXMO_DISABLE_LEDS="1"
-export SXMO_WAKEUPRTC="2"
-export SXMO_MODEMRTC="9999" # we don't have one of course
-export SXMO_POWERRTC="5" # same as pinephone
-export SXMO_COVERRTC="8" 
 export SXMO_MIN_BRIGHTNESS="0" # we can set brightness all the way down
 export SXMO_SYS_FILES="/sys/power/state /sys/power/mem_sleep /dev/rtc0"
 export SXMO_BMENU_LANDSCAPE_LINES="15"
