@@ -7,8 +7,5 @@ export SXMO_TOUCHSCREEN_ID=7
 export SXMO_MONITOR="DSI-1"
 export SXMO_POWER_BUTTON="1:1:gpio-keys"
 export SXMO_VOLUME_BUTTON="1:1:adc-keys"
-export SXMO_MODEMRTC=12
-export SXMO_POWERRTC=5
-export SXMO_WAKEUPRTC=3
 export SXMO_MODEM_GPIO_KEY_RI="1:1:gpio-key-ri"
 export SXMO_SWAY_SCALE="2"
