@@ -6,4 +6,4 @@
 export SXMO_DISABLE_LEDS="1"
 export SXMO_POWER_BUTTON="0:0:pm8941_pwrkey"
 export SXMO_VOLUME_BUTTON="1:1:GPIO_Buttons 0:0:pm8941_resin"
-export SXMO_SWAY_SCALE="2"
+export SXMO_SWAY_SCALE="1.5"
