@@ -16,12 +16,12 @@ stderr() {
 }
 
 cleanupnumber() {
-	if pn valid "$1"; then
+	if pnc valid "$1"; then
 		echo "$1"
 		return
 	fi
 
-	REFORMATTED="$(pn find ${DEFAULT_COUNTRY:+-c "$DEFAULT_COUNTRY"} "$1")"
+	REFORMATTED="$(pnc find ${DEFAULT_COUNTRY:+-c "$DEFAULT_COUNTRY"} "$1")"
 	if [ -n "$REFORMATTED" ]; then
 		echo "$REFORMATTED"
 		return
@@ -31,6 +31,8 @@ cleanupnumber() {
 }
 
 checkforfinishedcalls() {
+	exec 3<> "${XDG_RUNTIME_DIR:-HOME}/sxmo_modem.checkforfinishedcalls.lock"
+	flock -x 3
 	#find all finished calls
 	for FINISHEDCALLID in $(
 		mmcli -m any --voice-list-calls |
@@ -44,8 +46,7 @@ checkforfinishedcalls() {
 
 		rm -f "$XDG_RUNTIME_DIR/sxmo_calls/${FINISHEDCALLID}.monitoredcall"
 
-		CONTACT="$(sxmo_contacts.sh --name "$FINISHEDNUMBER")"
-		[ "$CONTACT" = "???" ] && CONTACT="$FINISHEDNUMBER"
+		CONTACT="$(sxmo_contacts.sh --name-or-number "$FINISHEDNUMBER")"
 
 		TIME="$(date +%FT%H:%M:%S%z)"
 		mkdir -p "$SXMO_LOGDIR"
@@ -57,7 +58,6 @@ checkforfinishedcalls() {
 		elif [ -f "$XDG_RUNTIME_DIR/sxmo_calls/${FINISHEDCALLID}.pickedupcall" ]; then
 			#this call was picked up
 			sxmo_notify_user.sh "Call with $CONTACT terminated"
-			sxmo_hook_statusbar.sh volume
 			stderr "Finished call from $FINISHEDNUMBER"
 			printf %b "$TIME\tcall_finished\t$FINISHEDNUMBER\n" >> "$SXMO_LOGDIR/modemlog.tsv"
 		elif [ -f "$XDG_RUNTIME_DIR/sxmo_calls/${FINISHEDCALLID}.hangedupcall" ]; then
@@ -68,7 +68,6 @@ checkforfinishedcalls() {
 		elif [ -f "$XDG_RUNTIME_DIR/sxmo_calls/${FINISHEDCALLID}.initiatedcall" ]; then
 			#this call was hung up by the contact
 			sxmo_notify_user.sh "Call with $CONTACT terminated"
-			sxmo_hook_statusbar.sh volume
 			stderr "Finished call from $FINISHEDNUMBER"
 			printf %b "$TIME\tcall_finished\t$FINISHEDNUMBER\n" >> "$SXMO_LOGDIR/modemlog.tsv"
 		elif [ -f "$XDG_RUNTIME_DIR/sxmo_calls/${FINISHEDCALLID}.mutedring" ]; then
@@ -78,8 +77,9 @@ checkforfinishedcalls() {
 		else
 			#this is a missed call
 			# Add a notification for every missed call
-			sxmo_hook_statusbar.sh volume
-			stderr "Missed call from $FINISHEDNUMBER"
+
+			NOTIFMSG="Missed call from $CONTACT ($FINISHEDNUMBER)"
+			stderr "$NOTIFMSG"
 			printf %b "$TIME\tcall_missed\t$FINISHEDNUMBER\n" >> "$SXMO_LOGDIR/modemlog.tsv"
 
 			stderr "Invoking missed call hook (async)"
@@ -87,9 +87,9 @@ checkforfinishedcalls() {
 
 			sxmo_notificationwrite.sh \
 				random \
-				"sxmo_terminal.sh -e sh -c \"echo 'Missed call from $CONTACT at $(date)' && read\"" \
+				"TERMNAME='$NOTIFMSG' sxmo_terminal.sh sh -c \"echo '$NOTIFMSG at $(date)' && read\"" \
 				none \
-				"Missed $icon_phn $CONTACT"
+				"Missed $icon_phn $CONTACT ($FINISHEDNUMBER)"
 		fi
 
 		# If it was the last call
@@ -97,7 +97,7 @@ checkforfinishedcalls() {
 			# Cleanup
 			sxmo_vibrate 1000 &
 			sxmo_daemons.sh stop incall_menu
-			sxmo_daemons.sh stop calling_proximity_lock
+			sxmo_daemons.sh stop proximity_lock
 
 			if ! sxmo_modemaudio.sh reset_audio; then
 				sxmo_notify_user.sh --urgency=critical "We failed to reset call audio"
@@ -125,7 +125,6 @@ checkforincomingcalls() {
 	stderr "Incoming Call..."
 	INCOMINGNUMBER=$(sxmo_modemcall.sh vid_to_number "$VOICECALLID")
 	INCOMINGNUMBER="$(cleanupnumber "$INCOMINGNUMBER")"
-	CONTACTNAME=$(sxmo_contacts.sh --name "$INCOMINGNUMBER")
 
 	TIME="$(date +%FT%H:%M:%S%z)"
 	if cut -f1 "$SXMO_BLOCKFILE" 2>/dev/null | grep -q "^$INCOMINGNUMBER$"; then
@@ -134,16 +133,13 @@ checkforincomingcalls() {
 		printf %b "$TIME\tcall_ring\t$INCOMINGNUMBER\n" >> "$SXMO_BLOCKDIR/modemlog.tsv"
 	else
 		stderr "Invoking ring hook (async)"
-		[ "$CONTACTNAME" = "???" ] && CONTACTNAME="$INCOMINGNUMBER"
+		CONTACTNAME=$(sxmo_contacts.sh --name-or-number "$INCOMINGNUMBER")
 		sxmo_hook_ring.sh "$CONTACTNAME" &
 
 		mkdir -p "$SXMO_LOGDIR"
 		printf %b "$TIME\tcall_ring\t$INCOMINGNUMBER\n" >> "$SXMO_LOGDIR/modemlog.tsv"
 
-		# do not duplicate proximity lock if already running
-		if ! (sxmo_daemons.sh running proximity_lock -q || sxmo_daemons.sh running calling_proximity_lock -q); then
-			sxmo_daemons.sh start calling_proximity_lock sxmo_hook_proximitylock.sh
-		fi
+		sxmo_daemons.sh start proximity_lock sxmo_proximitylock.sh
 
 		# If we already got an active call
 		if sxmo_modemcall.sh list_active_calls \
@@ -160,7 +156,32 @@ checkforincomingcalls() {
 	fi
 }
 
+# this function is called in the modem hook when the modem registers
+checkforstucksms() {
+	stuck_messages="$(mmcli -m any --messaging-list-sms)"
+	if ! echo "$stuck_messages" | grep -q "^No sms messages were found"; then
+		sxmo_notify_user.sh "WARNING: $(echo "$stuck_messages" | wc -l) stuck sms found.  Run sxmo_modem.sh checkforstucksms view to view or delete to delete."
+		case "$1" in
+			"delete")
+				mmcli -m any --messaging-list-sms | while read -r line; do
+					sms_number="$(echo "$line" | cut -d'/' -f6 | cut -d' ' -f1)"
+					sxmo_log "Deleting sms $sms_number"
+					mmcli -m any --messaging-delete-sms="$sms_number"
+				done
+				;;
+			"view")
+				mmcli -m any --messaging-list-sms | while read -r line; do
+					sms_number="$(echo "$line" | cut -d'/' -f6 | cut -d' ' -f1)"
+					mmcli -m any -s "$sms_number" -K
+				done
+				;;
+		esac
+	fi
+}
+
 checkfornewtexts() {
+	exec 3<> "${XDG_RUNTIME_DIR:-HOME}/sxmo_modem.checkfornewtexts.lock"
+	flock -x 3
 	TEXTIDS="$(
 		mmcli -m any --messaging-list-sms |
 		grep -Eo '/SMS/[0-9]+ \(received\)' |
@@ -196,18 +217,18 @@ checkfornewtexts() {
 		# later.
 		#
 		# TODO: a user *could* block the sms wap number (which would be user error).  But then
-		# the mms would not be processed.  So probably give a warning here if the user has blocked 
+		# the mms would not be processed.  So probably give a warning here if the user has blocked
 		# the sms wap number?
 		if cut -f1 "$SXMO_BLOCKFILE" 2>/dev/null | grep -q "^$NUM$"; then
 			mkdir -p "$SXMO_BLOCKDIR/$NUM"
 			stderr "BLOCKED text from number: $NUM (TEXTID: $TEXTID)"
-			printf %b "Received from $NUM at $TIME:\n$TEXT\n\n" >> "$SXMO_BLOCKDIR/$NUM/sms.txt"
+			sxmo_hook_smslog.sh "recv" "$NUM" "$NUM" "$TIME" "$TEXT" >> "$SXMO_BLOCKDIR/$NUM/sms.txt"
 			printf %b "$TIME\trecv_txt\t$NUM\t${#TEXT} chars\n" >> "$SXMO_BLOCKDIR/modemlog.tsv"
 			mmcli -m any --messaging-delete-sms="$TEXTID"
 			continue
 		fi
 
-		if [ "$TEXT" = "--" ]; then
+		if [ "$TEXT" = "--" ] && [ ! "$NUM" = "+223344556678" ]; then
 			stderr "Text from $NUM (TEXTID: $TEXTID) with '--'.  I will assume this is an MMS."
 			printf %b "$TIME\tdebug_mms\t$NUM\t$TEXT\n" >> "$SXMO_LOGDIR/modemlog.tsv"
 			if [ -f "${SXMO_MMS_BASE_DIR:-"$HOME"/.mms/modemmanager}/mms" ]; then
@@ -219,11 +240,10 @@ checkfornewtexts() {
 
 		mkdir -p "$SXMO_LOGDIR/$NUM"
 		stderr "Text from number: $NUM (TEXTID: $TEXTID)"
-		printf %b "Received SMS from $NUM at $TIME:\n$TEXT\n\n" >> "$SXMO_LOGDIR/$NUM/sms.txt"
+		sxmo_hook_smslog.sh "recv" "$NUM" "$NUM" "$TIME" "$TEXT" >> "$SXMO_LOGDIR/$NUM/sms.txt"
 		printf %b "$TIME\trecv_txt\t$NUM\t${#TEXT} chars\n" >> "$SXMO_LOGDIR/modemlog.tsv"
 		mmcli -m any --messaging-delete-sms="$TEXTID"
-		CONTACTNAME=$(sxmo_contacts.sh --name "$NUM")
-		[ "$CONTACTNAME" = "???" ] && CONTACTNAME="$NUM"
+		CONTACTNAME=$(sxmo_contacts.sh --name-or-number "$NUM")
 
 		if [ -z "$SXMO_DISABLE_SMS_NOTIFS" ]; then
 			sxmo_notificationwrite.sh \
@@ -231,6 +251,7 @@ checkfornewtexts() {
 				"sxmo_hook_tailtextlog.sh '$NUM'" \
 				"$SXMO_LOGDIR/$NUM/sms.txt" \
 				"$CONTACTNAME: $TEXT"
+
 		fi
 
 		if grep -q screenoff "$SXMO_STATE"; then
@@ -241,6 +262,6 @@ checkfornewtexts() {
 	done
 }
 
-sxmo_mutex.sh can_suspend lock "Modem is used"
+sxmo_wakelock.sh lock modem_used 30s
 "$@"
-sxmo_mutex.sh can_suspend free "Modem is used"
+sxmo_wakelock.sh unlock modem_used
