@@ -145,8 +145,7 @@ $(
 	list_active_calls | while read -r line; do
 		CALLID="$(printf %s "$line" | cut -d" " -f1 | xargs basename)"
 		NUMBER="$(vid_to_number "$CALLID")"
-		CONTACT="$(sxmo_contacts.sh --name "$NUMBER")"
-		[ "$CONTACT" = "???" ] && CONTACT="$NUMBER"
+		CONTACT="$(sxmo_contacts.sh --name-or-number "$NUMBER")"
 		case "$line" in
 			*"(ringing-in)")
 				# TODO switch to this call
@@ -190,14 +189,13 @@ mute() {
 	# this signals that we muted this ring
 	touch "$XDG_RUNTIME_DIR/sxmo_calls/${CALLID}.mutedring"
 	sxmo_log "Invoking mute_ring hook (async)"
-	sxmo_hook_mute_ring.sh "$CONTACTNAME" &
+	sxmo_hook_mute_ring.sh &
 	log_event "ring_mute" "$1"
 }
 
 incoming_call_menu() {
 	NUMBER="$(vid_to_number "$1")"
-	CONTACTNAME="$(sxmo_contacts.sh --name "$NUMBER")"
-	[ "$CONTACTNAME" = "???" ] && CONTACTNAME="$NUMBER"
+	CONTACTNAME="$(sxmo_contacts.sh --name-or-number "$NUMBER")"
 
 	if [ "$SXMO_WM" = "sway" ]; then
 		pickup_height="40"
@@ -207,7 +205,7 @@ incoming_call_menu() {
 
 	(
 		PICKED="$(
-			cat <<EOF | sxmo_dmenu.sh -i -H "$pickup_height" -p "$CONTACTNAME"
+			cat <<EOF | sxmo_dmenu.sh -i -H "$pickup_height" -p "$CONTACTNAME" -l 3
 $icon_phn Pickup
 $icon_phx Hangup
 $icon_mut Ignore
