@@ -18,7 +18,7 @@ dial_number() {
 
 	NUMBER="$1"
 
-	CLEANEDNUMBER="$(pn find ${DEFAULT_COUNTRY:+-c "$DEFAULT_COUNTRY"} "$1")"
+	CLEANEDNUMBER="$(pnc find ${DEFAULT_COUNTRY:+-c "$DEFAULT_COUNTRY"} "$1")"
 	if [ -n "$CLEANEDNUMBER" ] && [ "$NUMBER" != "$CLEANEDNUMBER" ]; then
 		NUMBER="$(cat <<EOF | sxmo_dmenu.sh -p "Rewrite ?"
 $NUMBER
@@ -52,10 +52,7 @@ EOF
 		return 1
 	fi
 
-	# do not duplicate proximity lock if already running
-	if ! sxmo_daemons.sh running proximity_lock -q; then
-		sxmo_daemons.sh start calling_proximity_lock sxmo_hook_proximitylock.sh
-	fi
+	sxmo_daemons.sh start proximity_lock sxmo_proximitylock.sh
 
 	sxmo_daemons.sh start incall_menu sxmo_modemcall.sh incall_menu
 }
@@ -66,7 +63,7 @@ dial_menu() {
 		grep . <<EOF | sxmo_dmenu_with_kb.sh -p Number -i
 Close Menu
 More contacts
-$(sxmo_contacts.sh)
+$(sxmo_contacts.sh --no-groups)
 EOF
 	)"
 
@@ -75,7 +72,7 @@ EOF
 		NUMBER="$(
 			grep . <<EOF | sxmo_dmenu_with_kb.sh -p Number -i
 Close Menu
-$(sxmo_contacts.sh --all)
+$(sxmo_contacts.sh --all --no-groups)
 EOF
 		)"
 	fi
