@@ -57,7 +57,7 @@ sendtextmenu() {
 	DRAFT="$SXMO_LOGDIR/$NUMBER/draft.txt"
 	if [ ! -f "$DRAFT" ]; then
 		mkdir -p "$(dirname "$DRAFT")"
-		echo "${SXMO_DEFAULT_DRAFT:-Enter text message here}" > "$DRAFT"
+		echo "$SXMO_DEFAULT_DRAFT" > "$DRAFT"
 	fi
 
 	# shellcheck disable=SC2086
@@ -65,19 +65,24 @@ sendtextmenu() {
 
 	while true
 	do
+		# We use them in printf statements
+		export icon_cls
+		export icon_att
+		export icon_usr
+
 		ATTACHMENTS=
 		if [ -f "$SXMO_LOGDIR/$NUMBER/draft.attachments.txt" ]; then
 			# shellcheck disable=SC2016
 			ATTACHMENTS="$(
 				tr '\n' '\0' < "$SXMO_LOGDIR/$NUMBER/draft.attachments.txt" |
-				xargs -0 -I{} sh -c 'printf "%s %s %s :: %s\n" "" "" "$(basename "{}")" "{}"'
+				xargs -0 -I{} sh -c 'printf "%s %s %s :: %s\n" "$icon_cls" "$icon_att" "$(basename "{}")" "{}"'
 			)"
 		fi
 
 		RECIPIENTS=
-		if [ "$(printf %s "$NUMBER" | xargs pn find | wc -l)" -gt 1 ]; then
+		if [ "$(printf %s "$NUMBER" | xargs pnc find | wc -l)" -gt 1 ]; then
 			# shellcheck disable=SC2016
-			RECIPIENTS="$(printf %s "$NUMBER" | xargs pn find | xargs -I{} sh -c 'printf "  "$(sxmo_contacts.sh --name {})" :: {}\n"')"
+			RECIPIENTS="$(printf %s "$NUMBER" | xargs pnc find | xargs -I{} sh -c 'printf "$icon_cls $icon_usr "$(sxmo_contacts.sh --name {})" :: {}\n"')"
 		fi
 
 		CHOICES="$(printf "%s Send to %s (%s)\n%b\n%s Add Recipient\n%b\n%s Add Attachment\n%s Edit '%s'\n%s Cancel\n" \
@@ -98,16 +103,16 @@ sendtextmenu() {
 				fi
 				;;
 			# Remove Attachment
-			" "*)
-				FILE="$(printf %s "$CONFIRM" | awk -F' :: ' '{print $2}')"  
+			"$icon_cls $icon_att"*)
+				FILE="$(printf %s "$CONFIRM" | awk -F' :: ' '{print $2}')"
 				sed -i "\|$FILE|d" "$SXMO_LOGDIR/$NUMBER/draft.attachments.txt"
 				if [ ! -s "$SXMO_LOGDIR/$NUMBER/draft.attachments.txt" ] ; then
 					rm "$SXMO_LOGDIR/$NUMBER/draft.attachments.txt"
 				fi
 				;;
 			# Remove Recipient
-			" "*)
-				if [ "$(printf %s "$NUMBER" | xargs pn find | wc -l)" -gt 1 ]; then 
+			"$icon_cls $icon_usr"*)
+				if [ "$(printf %s "$NUMBER" | xargs pnc find | wc -l)" -gt 1 ]; then
 					OLDNUMBER="$NUMBER"
 					RECIPIENT="$(printf %s "$CONFIRM" | awk -F' :: ' '{print $2}')"
 					NUMBER="$(printf %s "$OLDNUMBER" | sed "s/$RECIPIENT//")"
@@ -121,7 +126,6 @@ sendtextmenu() {
 						mv "$SXMO_LOGDIR/$OLDNUMBER/draft.attachments.txt" \
 							"$SXMO_LOGDIR/$NUMBER/draft.attachments.txt"
 					fi
-					kill "$(lsof | grep "/$OLDNUMBER/sms.txt" | cut -f1)"
 					[ -e "$SXMO_LOGDIR/$NUMBER/sms.txt" ] || touch "$SXMO_LOGDIR/$NUMBER/sms.txt"
 					sxmo_hook_tailtextlog.sh "$NUMBER" &
 				fi
@@ -144,7 +148,7 @@ sendtextmenu() {
 				elif echo "$OLDNUMBER" | grep -q "$ADDEDNUMBER"; then
 					echo "Number already a recipient."
 				else
-					NUMBER="$(printf %s%s "$NUMBER" "$ADDEDNUMBER" | xargs pn find | sort -u | tr -d '\n')"
+					NUMBER="$(printf %s%s "$NUMBER" "$ADDEDNUMBER" | xargs pnc find | sort -u | tr -d '\n')"
 					mkdir -p "$SXMO_LOGDIR/$NUMBER"
 					DRAFT="$SXMO_LOGDIR/$NUMBER/draft.txt"
 					if [ -f "$SXMO_LOGDIR/$OLDNUMBER/draft.txt" ]; then
@@ -155,7 +159,6 @@ sendtextmenu() {
 						mv "$SXMO_LOGDIR/$OLDNUMBER/draft.attachments.txt" \
 						"$SXMO_LOGDIR/$NUMBER/draft.attachments.txt"
 					fi
-					kill "$(lsof | grep "/$OLDNUMBER/sms.txt" | cut -f1)"
 					[ -e "$SXMO_LOGDIR/$NUMBER/sms.txt" ] || touch "$SXMO_LOGDIR/$NUMBER/sms.txt"
 					sxmo_hook_tailtextlog.sh "$NUMBER" &
 				fi
@@ -194,9 +197,11 @@ conversationloop() {
 
 readtextmenu() {
 	# E.g. only display logfiles for directories that exist and join w contact name
-	ENTRIES="$(
-	printf %b "$icon_cls Close Menu\n$icon_edt Send a Text\n";
-		sxmo_contacts.sh --texted | xargs -IL echo "L logfile"
+	ENTRIES="$(cat <<EOF
+$icon_cls Close Menu
+$icon_edt Send a Text
+$(sxmo_contacts.sh --texted)
+EOF
 	)"
 	PICKED="$(printf %b "$ENTRIES" | sxmo_dmenu_with_kb.sh -p "Texts" -i)" || exit
 
@@ -205,7 +210,7 @@ readtextmenu() {
 	elif echo "$PICKED" | grep "Send a Text"; then
 		sendtextmenu
 	else
-		sxmo_hook_tailtextlog.sh "$(echo "$PICKED" | cut -d: -f2 | sed 's/^ //' | cut -d' ' -f1 )"
+		sxmo_hook_tailtextlog.sh "$(echo "$PICKED" | cut -d: -f2 | sed 's/^ //')"
 	fi
 }
 
