@@ -8,14 +8,19 @@ case "$1" in
 		exit
 esac
 
-comment="#"
 case "$(busybox head -n1 "$1")" in
+	"#"*)
+		comment="#"
+		;;
 	!*)
 		comment="!"
 		;;
 	--*)
 		comment="--"
 		;;
+	*)
+		exit # we skip this file
+		;;
 esac
 
 busybox md5sum "$1" | \
