@@ -1,6 +1,3 @@
-# shellcheck disable=SC2155
-export PATH="$PATH:$(pwd)/scripts/core"
-
 # This file is to investigate whether sxmo_common.sh is loaded in tests
 
 Describe 'sxmo_common.sh'
